Enum CpuFeatureLevel
enum CpuFeatureLevel
Variants
-
RUST
Implementations
impl CpuFeatureLevel
fn variants() -> [&'static str; 1]Returns an array of valid values which can be converted into this enum.
fn descriptions() -> [(&'static [&'static str], &'static [&'static str]); 1]Returns an array of touples (variants, description)
impl Clone for CpuFeatureLevel
fn clone(self: &Self) -> CpuFeatureLevel
impl Copy for CpuFeatureLevel
impl Debug for CpuFeatureLevel
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for CpuFeatureLevel
fn default() -> CpuFeatureLevel
impl Display for CpuFeatureLevel
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for CpuFeatureLevel
impl Freeze for CpuFeatureLevel
impl FromStr for CpuFeatureLevel
fn from_str(s: &str) -> Result<Self, <Self as >::Err>
impl PartialEq for CpuFeatureLevel
fn eq(self: &Self, other: &CpuFeatureLevel) -> bool
impl PartialOrd for CpuFeatureLevel
fn partial_cmp(self: &Self, other: &CpuFeatureLevel) -> Option<Ordering>
impl RefUnwindSafe for CpuFeatureLevel
impl Send for CpuFeatureLevel
impl StructuralPartialEq for CpuFeatureLevel
impl Sync for CpuFeatureLevel
impl Unpin for CpuFeatureLevel
impl UnsafeUnpin for CpuFeatureLevel
impl UnwindSafe for CpuFeatureLevel
impl<T> Any for CpuFeatureLevel
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for CpuFeatureLevel
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for CpuFeatureLevel
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for CpuFeatureLevel
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for CpuFeatureLevel
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for CpuFeatureLevel
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for CpuFeatureLevel
fn to_string(self: &Self) -> String
impl<T, U> Into for CpuFeatureLevel
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for CpuFeatureLevel
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for CpuFeatureLevel
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>