Enum EncoderStatus
enum EncoderStatus
Status that can be returned by Context functions.
Variants
-
NeedMoreData The encoder needs more data to produce an output packet.
May be emitted by
Context::receive_packet()when frame reordering is enabled.-
EnoughData There are enough frames in the queue.
May be emitted by
Context::send_frame()when trying to send a frame after the encoder has been flushed.-
LimitReached The encoder has already produced the number of frames requested.
May be emitted by
Context::receive_packet()after a flush request had been processed or the frame limit had been reached.-
Encoded A frame had been encoded but not emitted yet.
-
Failure Generic fatal error.
-
NotReady A frame was encoded in the first pass of a 2-pass encode, but its stats data was not retrieved with
Context::twopass_out(), or not enough stats data was provided in the second pass of a 2-pass encode to encode the next frame.
Implementations
impl Clone for EncoderStatus
fn clone(self: &Self) -> EncoderStatus
impl Copy for EncoderStatus
impl Debug for EncoderStatus
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for EncoderStatus
fn fmt(self: &Self, __formatter: &mut Formatter<'_>) -> Result
impl Eq for EncoderStatus
impl Error for EncoderStatus
impl Freeze for EncoderStatus
impl PartialEq for EncoderStatus
fn eq(self: &Self, other: &EncoderStatus) -> bool
impl RefUnwindSafe for EncoderStatus
impl Send for EncoderStatus
impl StructuralPartialEq for EncoderStatus
impl Sync for EncoderStatus
impl Unpin for EncoderStatus
impl UnsafeUnpin for EncoderStatus
impl UnwindSafe for EncoderStatus
impl<T> Any for EncoderStatus
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for EncoderStatus
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for EncoderStatus
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for EncoderStatus
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for EncoderStatus
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for EncoderStatus
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for EncoderStatus
fn to_string(self: &Self) -> String
impl<T, U> Into for EncoderStatus
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for EncoderStatus
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for EncoderStatus
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>