Struct FrameParameters
struct FrameParameters { ... }
Optional per-frame encoder parameters
Fields
frame_type_override: FrameTypeOverrideForce emitted frame to be of the type selected
opaque: Option<Opaque>Output the provided data in the matching encoded Packet
t35_metadata: Box<[T35]>List of t35 metadata associated with this frame
Implementations
impl Debug for FrameParameters
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for FrameParameters
fn default() -> FrameParameters
impl Freeze for FrameParameters
impl RefUnwindSafe for FrameParameters
impl Send for FrameParameters
impl Sync for FrameParameters
impl Unpin for FrameParameters
impl UnsafeUnpin for FrameParameters
impl UnwindSafe for FrameParameters
impl<T> Any for FrameParameters
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FrameParameters
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FrameParameters
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for FrameParameters
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for FrameParameters
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FrameParameters
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FrameParameters
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>