Struct Packet
struct Packet<T: Pixel> { ... }
Represents a packet.
A packet contains one shown frame together with zero or more additional frames.
Fields
data: Vec<u8>The packet data.
rec: Option<Arc<Frame<T>>>The reconstruction of the shown frame.
source: Option<Arc<Frame<T>>>The Reference Frame
input_frameno: u64The number of the input frame corresponding to the one shown frame in the TU stored in this packet. Since AV1 does not explicitly reorder frames, these will increase sequentially.
frame_type: FrameTypeType of the shown frame.
qp: u8QP selected for the frame.
enc_stats: EncoderStatsBlock-level encoding stats for the frame
opaque: Option<Opaque>Optional user-provided opaque data
Implementations
impl<T> Any for Packet<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Packet<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Packet<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for Packet<T>
impl<T> From for Packet<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for Packet<T>
impl<T> Send for Packet<T>
impl<T> Sync for Packet<T>
impl<T> ToString for Packet<T>
fn to_string(self: &Self) -> String
impl<T> Unpin for Packet<T>
impl<T> UnsafeUnpin for Packet<T>
impl<T> UnwindSafe for Packet<T>
impl<T, U> Into for Packet<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Packet<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Packet<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::fmt::Debug + Pixel> Debug for Packet<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: Pixel> Display for Packet<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: Pixel> PartialEq for Packet<T>
fn eq(self: &Self, other: &Self) -> bool