Enum PredictionModesSetting
enum PredictionModesSetting
Prediction modes to search.
Variants
-
Simple Only simple prediction modes.
-
ComplexKeyframes Search all prediction modes on key frames and simple modes on other frames.
-
ComplexAll Search all prediction modes on all frames.
Implementations
impl Clone for PredictionModesSetting
fn clone(self: &Self) -> PredictionModesSetting
impl Copy for PredictionModesSetting
impl Debug for PredictionModesSetting
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for PredictionModesSetting
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for PredictionModesSetting
impl Freeze for PredictionModesSetting
impl FromPrimitive for PredictionModesSetting
fn from_i64(n: i64) -> Option<Self>fn from_u64(n: u64) -> Option<Self>
impl PartialEq for PredictionModesSetting
fn eq(self: &Self, other: &PredictionModesSetting) -> bool
impl PartialOrd for PredictionModesSetting
fn partial_cmp(self: &Self, other: &PredictionModesSetting) -> Option<Ordering>
impl RefUnwindSafe for PredictionModesSetting
impl Send for PredictionModesSetting
impl StructuralPartialEq for PredictionModesSetting
impl Sync for PredictionModesSetting
impl Unpin for PredictionModesSetting
impl UnsafeUnpin for PredictionModesSetting
impl UnwindSafe for PredictionModesSetting
impl<T> Any for PredictionModesSetting
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PredictionModesSetting
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PredictionModesSetting
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for PredictionModesSetting
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for PredictionModesSetting
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for PredictionModesSetting
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for PredictionModesSetting
fn to_string(self: &Self) -> String
impl<T, U> Into for PredictionModesSetting
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PredictionModesSetting
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PredictionModesSetting
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>