Enum PredictionMode
enum PredictionMode
Variants
-
DC_PRED -
V_PRED -
H_PRED -
D45_PRED -
D135_PRED -
D113_PRED -
D157_PRED -
D203_PRED -
D67_PRED -
SMOOTH_PRED -
SMOOTH_V_PRED -
SMOOTH_H_PRED -
PAETH_PRED -
UV_CFL_PRED -
NEARESTMV -
NEAR0MV -
NEAR1MV -
NEAR2MV -
GLOBALMV -
NEWMV -
NEAREST_NEARESTMV -
NEAR_NEAR0MV -
NEAR_NEAR1MV -
NEAR_NEAR2MV -
NEAREST_NEWMV -
NEW_NEARESTMV -
NEAR_NEW0MV -
NEAR_NEW1MV -
NEAR_NEW2MV -
NEW_NEAR0MV -
NEW_NEAR1MV -
NEW_NEAR2MV -
GLOBAL_GLOBALMV -
NEW_NEWMV
Implementations
impl PredictionMode
fn is_compound(self: Self) -> boolfn has_nearmv(self: Self) -> boolfn has_newmv(self: Self) -> boolfn ref_mv_idx(self: Self) -> usizefn predict_intra<T: Pixel>(self: Self, tile_rect: TileRect, dst: &mut PlaneRegionMut<'_, T>, tx_size: TxSize, bit_depth: usize, ac: &[i16], intra_param: IntraParam, ief_params: Option<IntraEdgeFilterParameters>, edge_buf: &IntraEdge<'_, T>, cpu: CpuFeatureLevel)Panics
- If called on an inter
PredictionMode
- If called on an inter
fn is_intra(self: Self) -> boolfn is_cfl(self: Self) -> boolfn is_directional(self: Self) -> boolconst fn angle_delta_count(self: Self) -> i8fn predict_inter_single<T: Pixel>(self: Self, fi: &FrameInvariants<T>, tile_rect: TileRect, p: usize, po: PlaneOffset, dst: &mut PlaneRegionMut<'_, T>, width: usize, height: usize, ref_frame: RefType, mv: MotionVector)Inter prediction with a single reference (i.e. not compound mode)
Panics
- If called on an intra
PredictionMode
- If called on an intra
fn predict_inter_compound<T: Pixel>(self: Self, fi: &FrameInvariants<T>, tile_rect: TileRect, p: usize, po: PlaneOffset, dst: &mut PlaneRegionMut<'_, T>, width: usize, height: usize, ref_frames: [RefType; 2], mvs: [MotionVector; 2], buffer: &mut InterCompoundBuffers)Inter prediction with two references.
Panics
- If called on an intra
PredictionMode
- If called on an intra
fn predict_inter<T: Pixel>(self: Self, fi: &FrameInvariants<T>, tile_rect: TileRect, p: usize, po: PlaneOffset, dst: &mut PlaneRegionMut<'_, T>, width: usize, height: usize, ref_frames: [RefType; 2], mvs: [MotionVector; 2], compound_buffer: &mut InterCompoundBuffers)Inter prediction that determines whether compound mode is being used based on the second
RefTypeinref_frames.
impl Clone for PredictionMode
fn clone(self: &Self) -> PredictionMode
impl Copy for PredictionMode
impl Debug for PredictionMode
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for PredictionMode
fn default() -> PredictionMode
impl Eq for PredictionMode
impl Freeze for PredictionMode
impl Ord for PredictionMode
fn cmp(self: &Self, other: &PredictionMode) -> Ordering
impl PartialEq for PredictionMode
fn eq(self: &Self, other: &PredictionMode) -> bool
impl PartialOrd for PredictionMode
fn partial_cmp(self: &Self, other: &PredictionMode) -> Option<Ordering>
impl RefUnwindSafe for PredictionMode
impl Send for PredictionMode
impl StructuralPartialEq for PredictionMode
impl Sync for PredictionMode
impl Unpin for PredictionMode
impl UnsafeUnpin for PredictionMode
impl UnwindSafe for PredictionMode
impl<T> Any for PredictionMode
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PredictionMode
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PredictionMode
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for PredictionMode
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for PredictionMode
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for PredictionMode
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for PredictionMode
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PredictionMode
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PredictionMode
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>