Enum Tune
enum Tune
Variants
-
Psnr -
Psychovisual
Implementations
impl Tune
fn variants() -> [&'static str; 2]Returns an array of valid values which can be converted into this enum.
fn descriptions() -> [(&'static [&'static str], &'static [&'static str]); 2]Returns an array of touples (variants, description)
impl Clone for Tune
fn clone(self: &Self) -> Tune
impl Copy for Tune
impl Debug for Tune
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Tune
fn default() -> Tune
impl Display for Tune
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Tune
impl Freeze for Tune
impl FromStr for Tune
fn from_str(s: &str) -> Result<Self, <Self as >::Err>
impl PartialEq for Tune
fn eq(self: &Self, other: &Tune) -> bool
impl RefUnwindSafe for Tune
impl Send for Tune
impl StructuralPartialEq for Tune
impl Sync for Tune
impl Unpin for Tune
impl UnsafeUnpin for Tune
impl UnwindSafe for Tune
impl<T> Any for Tune
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Tune
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Tune
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Tune
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Tune
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Tune
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Tune
fn to_string(self: &Self) -> String
impl<T, U> Into for Tune
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Tune
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Tune
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>